@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # Debugger Edit command
 
-#   Copyright (C) 2008, 2010 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2008, 2010, 2011 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -12,7 +12,7 @@
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 #   General Public License for more details.
-#   
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; see the file COPYING.  If not, write to
 #   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
@@ -21,16 +21,18 @@
 #================ VARIABLE INITIALIZATIONS ====================#
 
 _Dbg_help_add edit \
-"edit [LOCATION] -- Edit specified file at LOCATION.
+"**edit** [*line-number*]
 
-If LOCATION is not given, use the current location. 
-Uses EDITOR environment variable contents as editor (or ex as default).
-Assumes the editor positions at a file using options +linenumber filename."
+Edit specified file at *line-number*.
+
+If *line-number* is not given, use the current line number.
+Uses \"EDITOR\" environment variable contents as editor (or ex as default).
+Assumes the editor positions at a file using options \"+linenumber filename\"."
 
 _Dbg_do_edit() {
-  if (($# > 2)) ; then 
+  if (($# > 2)) ; then
       _Dbg_errmsg "got $# parameters, but need 0 or 1."
-      return 1
+      return 2
   fi
   typeset editor=${EDITOR:-ex}
   typeset -i line_number
@@ -40,7 +42,7 @@ _Dbg_do_edit() {
   else
     _Dbg_linespec_setup "$1"
   fi
-  if [[ ! -r $full_filename ]]  ; then 
+  if [[ ! -r $full_filename ]]  ; then
       _Dbg_errmsg "File $full_filename is not readable"
       return 2
   fi
