@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # "show autoeval" debugger command
 #
-#   Copyright (C) 2010, 2011 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2010-2011, 2019 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -19,11 +19,13 @@
 #   MA 02111 USA.
 
 _Dbg_help_add_sub show autoeval \
-'show autoeval
+'**show autoeval**
 
 Show whether unrecognized commands are automatically evaluated.
 
-See also \"set autoeval\".' 1
+See also:
+---------
+**set autoeval**.' 1
 
 _Dbg_do_show_autoeval() {
     [[ -n $1 ]] && label=$(_Dbg_printf_nocr "%-12s: " autoeval)
