@@ -1,7 +1,8 @@
 # -*- shell-script -*-
 # gdb-like "skip" (step over) commmand.
 #
-#   Copyright (C) 2010 Rocky Bernstein rocky@gnu.org
+#   Copyright (C) 2010, 2011, 2017, 2024
+#   Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -12,26 +13,44 @@
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 #   General Public License for more details.
-#   
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; see the file COPYING.  If not, write to
 #   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
 #   MA 02111 USA.
 
-# Sets whether or not to display command to be executed in debugger prompt.
-# If yes, always show. If auto, show only if the same line is to be run
-# but the command is different.
-
 _Dbg_help_add skip \
-"skip [COUNT]	-- Skip (don't run) the next COUNT command(s).
+"**skip** [*count*]
 
-If COUNT is given, stepping occurs that many times before
-stopping. Otherwise COUNT is one. COUNT an be an arithmetic
-expression. See also \"next\" and \"step\"."
+Skip over (don't run) the next *count* command(s).
+
+If *count* is given, stepping occurs that many times before
+stopping. Otherwise *count* is one. *count* can be an arithmetic
+expression.
+
+Note that skipping doesn't change the value of \$?. This has
+consequences in some compound statements that test on \$?. For example
+in:
+
+   if grep foo bar.txt ; then
+      echo not skipped
+   fi
+
+Skipping the *if* statement will, in effect, skip running the *grep*
+command. Since the return code is 0 when skipped, the *if* body is
+entered. Similarly the same thing can  happen in a *while* statement
+test.
+
+See http://lists.gnu.org/archive/html/bug-bash/2017-04/msg00004.html
+
+See also:
+---------
+
+**next**, **step**, and **continue**.
+"
 
 _Dbg_do_skip() {
     _Dbg_last_cmd='skip'
-    _Dbg_next_skip_common 1 $*
+    _Dbg_next_skip_common 1 $@
     return $?
 }
-
