@@ -2,21 +2,22 @@
 # Things related to variable journaling.
 #
 #   Copyright (C) 2002, 2003, 2004, 2006, 2008, 2009,
-#   2010 Rocky Bernstein rocky@gnu.org
+#   2010, 2011 Rocky Bernstein <rocky@gnu.org>
 #
-#   bashdb is free software; you can redistribute it and/or modify it under
-#   the terms of the GNU General Public License as published by the Free
-#   Software Foundation; either version 2, or (at your option) any later
-#   version.
+#   This program is free software; you can redistribute it and/or
+#   modify it under the terms of the GNU General Public License as
+#   published by the Free Software Foundation; either version 2, or
+#   (at your option) any later version.
 #
-#   bashdb is distributed in the hope that it will be useful, but WITHOUT ANY
-#   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-#   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-#   for more details.
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+#   General Public License for more details.
 #   
-#   You should have received a copy of the GNU General Public License along
-#   with bashdb; see the file COPYING.  If not, write to the Free Software
-#   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+#   You should have received a copy of the GNU General Public License
+#   along with this program; see the file COPYING.  If not, write to
+#   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
+#   MA 02111 USA.
 
 # We use a journal file to save variable state so that we can pass
 # values set in a subshell or nested shell back. This typically
@@ -28,8 +29,8 @@ typeset _Dbg_journal=$(_Dbg_tempname journal)
 
 # append a command into journal file and then run the command.
 _Dbg_write_journal_eval() {
-    _Dbg_write_journal "$*" 
-    eval "$*"
+    _Dbg_write_journal "$@" 
+    eval "$@"
 }
 
 # append a command into journal file and then run the command.
@@ -42,7 +43,7 @@ _Dbg_write_journal_var() {
 }
 
 _Dbg_write_journal_avar() {
-    typeset decl_str=$(declare -p $1)
+    typeset decl_str; decl_str=$(declare -p $1)
     typeset -a decl_a
     decl_a=($decl_str)
     typeset -a decl_a2
@@ -53,22 +54,23 @@ _Dbg_write_journal_avar() {
 # Append a command into journal file. But we only need to do
 # if we are in a subshell.
 _Dbg_write_journal() {
-    if (( $BASH_SUBSHELL != 0 )) ; then
-	echo "$@" >> ${_Dbg_journal} 2>/dev/null
+    if (( BASH_SUBSHELL != 0 )) ; then
+        echo "$@" >> ${_Dbg_journal} 2>/dev/null
     fi
     # return $?
 }
 
 # Remove all journal files.
 _Dbg_erase_journals() {
-    rm ${_Dbg_journal} 2>/dev/null
+    [[ -f $_Dbg_journal ]] && rm ${_Dbg_journal} 2>/dev/null
+    return $?
 }
 
 # read in or "source" in journal file which will set variables.
 _Dbg_source_journal() {
 
   if [ -r $_Dbg_journal ] ; then 
-    . $_Dbg_journal
+    . "$_Dbg_journal"
     (( BASH_SUBSHELL == 0 )) && _Dbg_erase_journals
   fi
 }
